function Fout = PulseShaping (Fin)
% Version 1.2
% Last Modified: May 24th, 2009
% Ali Tawfiq
% Multimedia Labratory, The Edward S. Rogers Sr. Dept of Electrical and
% Computer Engineering, University of Toronto

%**************************************************************************
%       Fout    -> L: Length of signal
%               -> itt: number of iterations
%               -> Mod: Modulation Type (refer to 'Mapping.m' for allowed
%                        types)
%               -> M: M-ary, binary (2), quade (4) or 2^n
%               -> k: Number of bits per symbol
%               -> Block: String for block type (refer to 'Mapping.m')
%               -> BlockL: Length of blocks (refer to 'Mapping.m')
%               -> Numtx: Number of transmit antennas
%               -> Numrx: Number of receive antennas
%               -> SNR: a vector of SNR values
%               -> sBER: a temporary vector to store the computed BER
%               -> BER: a zero vector to store the computed BER
%               -> Out: a zero vector to store the final received signal
%                       to be be saved for reference
%               -> InSig: The input signal in bits
%               -> S: Numtx column vectors representing the split input
%                      signal
%               -> Saving: 'backup' for saving the data. 
%               -> InSym: Numtx column vectors of the modulated signal.
%               -> Px: Power of signal (1 for all psk, diff for QAM)
%               Filter Parameters:
%               -> r: Roll-off-factor Used in raised cosine filter
%               -> T: Bit period
%               -> dur:  Duration
%               -> FltrType: The type of filter generated. 
%               -> nsamp: oversampling rate
%               Parameters added in this module:
%               -> Delay: The delay experienced in the filter
%               -> fltr: The generated filter (To be applied in Transmit.m
%                        and Receiver.m)
%**************************************************************************
addpath ./'Pulse Shaping'
%% ================== Pulse Shapping ======================
%%========================================================
Fout = Fin; 
% Define filter-related parameters.
dt= Fout.T/Fout.nsamp;
Fout.Delay = floor(Fout.dur/dt); % Group delay

% Create the Filter
switch (Fout.FltrType)
    case('sqrtrcos')
        % This function generates a square root raised cosine filter
        Filter = sqrtrcos(Fout.dur,dt,Fout.r,Fout.T);
    case('sqrttrrcos')
        % This function generates a truncated square root raised cosine 
        % filter
        Truncation= 0.5; %in the range of 0-1
        Filter = sqrttrrcos(Fout.dur,dt,Truncation,Fout.T);
    case('sqrtmrcos')
        % This function generates a modified square root raised cosine 
        % filter
        Filter = sqrtmrcos(Fout.dur,dt,Fout.r,Fout.T);
    case('sqrtsfrcos')
        % This function generates a shifted square root raised cosine 
        % filter
        Shift= 5;
        Filter = sqrtsfrcos(Fout.dur,dt,Fout.r,Fout.T,Shift);
    otherwise
        error('*** Filter Type not Available ***');
end
Fout.fltr = Filter ./ max(abs(Filter)); % Normalize the filter
 
    
    